@@ -1,5 +1,5 @@
 from .sgd import SGD
 from .rmsprop import RMSprop
 from .adam import Adam
-# from .adamw import AdamW
+from .adamw import AdamW
 from .optimizer import Optimizer
